Crate rustsim_broadphase

Crate rustsim_broadphase 

Broadphase spatial acceleration structures for rustsim.

Provides efficient neighbour queries for dense populations of agents. Currently implemented:

Both structures use a single scalar cell size. Choose a cell size close to the expected query radius for best pruning.

Re-exports

pub use uniform_grid_2d::UniformGrid2;
pub use uniform_grid_3d::UniformGrid3;

Modules

prelude
Convenience re-exports.
uniform_grid_2d
2-D uniform hash-grid broadphase.
uniform_grid_3d
3-D uniform hash-grid broadphase.