pub struct UniformGrid3 {
pub cell_size: f64,
/* private fields */
}Expand description
Uniform hash-grid indexing points in 3-D by cell coordinate.
Fields
cell_size: f64Cell edge length (metres).
Implementations
Sourceimpl UniformGrid3
impl UniformGrid3
Sourcepub fn new(cell_size: f64) -> Self
pub fn new(cell_size: f64) -> Self
Construct a grid with the given cell size (metres).
Panics
Panics if cell_size is not strictly positive.
Sourcepub fn insert_all<I: IntoIterator<Item = (u64, Vec3)>>(&mut self, iter: I)
pub fn insert_all<I: IntoIterator<Item = (u64, Vec3)>>(&mut self, iter: I)
Insert many (key, pos) pairs.
Sourcepub fn query_radius(&self, center: Vec3, radius: f64) -> Vec<u64>
pub fn query_radius(&self, center: Vec3, radius: f64) -> Vec<u64>
Return all keys within Euclidean distance radius of center.